Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1900)

Unified Diff: net/http/http_network_session.h

Issue 2089243002: Split enable_alternative_service_with_different_host flag. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_network_session.h
diff --git a/net/http/http_network_session.h b/net/http/http_network_session.h
index 1270ce52d1b7780c7859ebe4ebf988bfd5040f4d..2c81a9afa8ab957bb1dc3800682a68849d1042e1 100644
--- a/net/http/http_network_session.h
+++ b/net/http/http_network_session.h
@@ -94,9 +94,12 @@ class NET_EXPORT HttpNetworkSession
size_t spdy_stream_max_recv_window_size;
// Source of time for SPDY connections.
SpdySessionPool::TimeFunc time_func;
- // Whether to enable Alt-Svc entries with hostname different than that of
- // the origin.
- bool enable_alternative_service_with_different_host;
+ // Whether to enable HTTP/2 Alt-Svc entries with hostname different than
+ // that of the origin.
+ bool enable_http2_alternative_service_with_different_host;
+ // Whether to enable QUIC Alt-Svc entries with hostname different than that
+ // of the origin.
+ bool enable_quic_alternative_service_with_different_host;
// Only set for tests.
// TODO(bnc) https://crbug.com/615497:
// Adapt tests to https requests, remove this member.

Powered by Google App Engine
This is Rietveld 408576698